%function [data_out] = Abs_Curves10b(TC_reading,pp_85,pp_87,data,color)
function [data_out] = Abs_Curves10b(TC_reading,pp_85,pp_87,color)

%TC_reading=thermocouple reading for data run 
%pp_87 pumping percentage Rb87 
%pp_85 pumping percentage Rb85 
%example usage:
%data=Abs_Curves10b(4,.9,.9,'r');
%data experimental data run 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%       Program  for Calculating Rb Cell Absorption Curves
%                                                       
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Zach Simmons

%significant revisions:
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%started week of 12-13-2010
%12-17-2010 got susceptibility working (i think*) with Rb-87 D2 lines 
%1-5-2011 added Rb-85
%1-6-2011 absorption incorporated
%1-7-2011 abundances: helped with overall shape, still looks weird like 
%i need a shorter cell or equivalent to get the behavior to match Nick's more closely
%1-10-2011 integration: increasing size of integration helped with
%smoothness of curves..
%1-19-2011 lowered step size to 100MHz, makes the program MUCH faster.  I
%don't know why i had it in my head it had to plot a point every few MHz
%1-21-2011 Deniz helped me track down some factors.  One is the
%distribution of the population in the two hyperfine groundstates, 
%since there are a total of 5 mf levels on F=2 and 3 on F=1, and they're
%all evenly distributed, 5/8 will be in F=2, 3/8 will be in F=1.  Also,
%since the laser appears isotropic, since the mf's are all degenerate, i
%need an overall factor of 1/3
%Smoothness of integration: upping the accuracy of the integration routine
%seemed to fix the smoothness issue as well.  Apparently the default is
%1E-6.  upped it to 1E-9;
%1-31-2011 Pumping should finally be straightened out.
%2-2-2011 Distinguished pumping Rb87 from Rb85
%2-2-2011 inserted factor of 2*pi on pressure broadening.
%2-8-2011 after looking at papers, using more like 21MHz/torr instead 
%of 29MHz/Torr for pressure broadening
%4-22-2011 Fixed a logic issue with pumping to accomidate pumping
%'backwards' i.e. 85% pumping Rb85 F=3->F=2 set pp_85=.85, 85% pumping Rb85
%F=2->F=3 set pp_85=-.85, 

%general scheme: 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%matrix elements, resonant frequences, linewidiths+
%doppler broadening+
%density(T)->
%linear susceptibility->
%absorption as a fn of freq

%from lasers notes: 
%chi=2/(hbar*epsilon_0)*u12^2*N*1/(2*(wa-w)+j*gamma)



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%               Fixed Numbers: Matrix Elements, etc.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%from Steck, all the constants and matrix elements, etc..
%constants:
hbar=1.05457E-34;
e_0=8.85E-12;
e=1.602E-19;
a0=.5E-10;
c=3.0E8;
kb=1.3806504E-23;
%T=273+100;
mRb87=1.44316060E-25;
mRb85=1.409993199E-25;
%Rb-87numbers%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%General s=1/2 to p=3/2 properties:
wa_Rb87_stop3=2*pi*384.2304844685E12;
%gamma_Rb87_stop3=2*pi*6.065E6;
%gamma is pressure broadened, 29MHz/torr buffer gas
%? buffer gas pressure changes with temp right?  
%10torr at room temp -> 1/30 torr/K
%buffer_gas_pressure=1/30*
%gamma_Rb87_stop3=2*pi*6.0666E6+29E6*10*4/3;%investigate pressure broadening 
%u_stop3=4.22752*e*a0;

%F=2 properties
%check 2pi
gs_detuning=-2.5630059790891091E9*2*pi;
es_detuning_1=-229.8518E6*2*pi;
es_detuning_2=-72.9112E6*2*pi;
es_detuning_3=193.7407E6*2*pi;

%F=2 matrix elements
%transition strength factors relationship to matrix elements?
%ask nick about factors of 1/3 in Steck
S23=7/10;
S22=1/4;
S21=1/20;

%F=1 properties
%check 2pi
gs_detuning1=4.271676631815181E9*2*pi;
es_detuning1_0=-302.0738E6*2*pi;
es_detuning1_1=-229.8518E6*2*pi;
es_detuning1_2=-72.9112E6*2*pi;

%F=1 matrix elements
S12=5/12;
S11=5/12;
S10=1/6;

%Rb-85numbers%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%General s=1/2 to p=3/2 properties:

wa_Rb85_stop3=2*pi*384.230406373E12;
%gamma_Rb85_stop3=2*pi*6.0666E6;
%gamma_Rb85_stop3=2*pi*6.0666E6+29E6*10;
u_stop3=4.22753*e*a0;

%F=2 properties
gs_detuning2=1.7708439228E9*2*pi;
es_detuning2_1=-113.208E6*2*pi;
es_detuning2_2=-83.835E6*2*pi;
es_detuning2_3=-20.435E6*2*pi;

%F=2 matrix elements
Sb23=14/45;
Sb22=7/18;
Sb21=3/10;

%F=3 properties
gs_detuning3=-1.2648885163E9*2*pi;
es_detuning3_2=-83.835E6*2*pi;
es_detuning3_3=-20.435E6*2*pi;
es_detuning3_4=100.205E6*2*pi;

%F=3 matrix elements
S34=9/14;
S33=5/18;
S32=5/63;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%           user spec'd numbers
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%cell length
%note: length changed to 30 microns
L=1E-3;
%L=30E-6;
%L=100E-6;

%N=5.6E12*100^3;
TCV=TC_reading;
[density_percc,T]=Calc_Density(TCV)
N=density_percc*100^3; %/cc->/m^3
N=N*1/3;  %appears 1/3 smaller because of isotropic-ness of laser since all 
%the mf's are degenerate

%pressure broadening transplanted from above
%gamma is pressure broadened, 29MHz/torr buffer gas
%? buffer gas pressure changes with temp right?  
%10torr at room temp -> 1/30 torr/K
buffer_gas_pressure=1/30*(T+273);
%gamma_Rb87_stop3=2*pi*6.0666E6+29E6*buffer_gas_pressure*pi;%*2*pi;%investigate pressure broadening 
gamma_Rb87_stop3=2*pi*6.0666E6+21.5E6*buffer_gas_pressure*2*pi;%*2*pi;%investigate pressure broadening 

gamma_Rb85_stop3=gamma_Rb87_stop3;
%need a 2pi on the pressure broadening? the 2pi factor does seem to help
%simulation agreement, 
u_stop3=4.22752*e*a0;

%pumping

if pp_85<0
%if it's negative pumping, i.e. Rb85 F=2->F=3:
pumped_left_85=1+pp_85;
pumped_out_85=-1*pp_85;
Rb_85_F2_factor=5/12*pumped_left_85;
Rb_85_F3_factor=7/12+5/12*pumped_out_85;
else
%if it's positive pumping, i.e. Rb85 F=3->F=2:
pumped_left_85=1-pp_85;
pumped_out_85=pp_85;
Rb_85_F3_factor=7/12*pumped_left_85;
Rb_85_F2_factor=5/12+7/12*pumped_out_85;
end

if pp_87<0
%if it's negative pumping, i.e. Rb85 F=1->F=2:
pumped_left_87=1+pp_87;
pumped_out_87=-1*pp_87;
Rb_87_F1_factor=3/8*pumped_left_87;
Rb_87_F2_factor=5/8+3/8*pumped_out_87;
else
%if it's positive pumping, i.e. Rb85 F=2->F=1:
pumped_left_87=1-pp_87;
pumped_out_87=pp_87;
Rb_87_F2_factor=5/8*pumped_left_87;
Rb_87_F1_factor=3/8+5/8*pumped_out_87;
end

pumped_left_87=1-pp_87;
pumped_out_87=pp_87;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%next we need to incorporate doppler broadening.
%below is the dopler linewidth as a function of T:
delta_wd=sqrt((8*log(2)*kb*(T+273)/(mRb87*c^2)))*(wa_Rb87_stop3+gs_detuning)*1;
%delta_wd=2*pi*200E6;
%question: can we use the same width for all the doppler broadenings? i
%think we can since it's so broad..

constant=2*N*u_stop3^2/(hbar*e_0); %factor out front of the susceptibility
%how about lets go 1000 MhZ to either side of the transiton

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%           Main Program Loop
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%better pre-allocate space.
index=1;
for w=wa_Rb87_stop3-6E9*6:100E6:wa_Rb87_stop3+8E9*6
    index=index+1;
end
chi=zeros(index-1,2);
chi2=zeros(index-1,2);
abs=zeros(index-1,1);

%heres the actual loop
  %integrating over wa, i.e. over the resonance frequency should give one 
  %point on the susceptibility curve at that particular w in the for loop.
index=1;
for w=(wa_Rb87_stop3-6E9*6):100E6:(wa_Rb87_stop3+8E9*6)
   %note: the .28 and .72 that appear in these expressions are the
   %abundances for the 2 Rb isotopes, the 3/8, 5/8, 5/12, 7/12 that appear are
   %because of the distribution of the population in the two hyperfine
   %groundstates for each 
   %susceptibility (unbroadened) 
   chi(index,1)=w;
   chi(index,2)=constant...%N is burried inside 'constant'
        *(.28*(Rb_87_F2_factor*(S21/(2*(wa_Rb87_stop3+gs_detuning+es_detuning_1-w)+1j*gamma_Rb87_stop3)...%Rb-87 F=2
       +S22/(2*(wa_Rb87_stop3+gs_detuning+es_detuning_2-w)+1j*gamma_Rb87_stop3)...%Rb-87 F=2
       +S23/(2*(wa_Rb87_stop3+gs_detuning+es_detuning_3-w)+1j*gamma_Rb87_stop3))...%Rb-87 F=2
       +(Rb_87_F1_factor)*(S10/(2*(wa_Rb87_stop3+gs_detuning1+es_detuning1_0-w)+1j*gamma_Rb87_stop3)...%Rb-87 F=1
       +S11/(2*(wa_Rb87_stop3+gs_detuning1+es_detuning1_1-w)+1j*gamma_Rb87_stop3)...%Rb-87 F=1
       +S12/(2*(wa_Rb87_stop3+gs_detuning1+es_detuning1_2-w)+1j*gamma_Rb87_stop3)))...%Rb-87 F=1
       +.72*((Rb_85_F2_factor)*(Sb23/(2*(wa_Rb87_stop3+gs_detuning2+es_detuning2_3-w)+1j*gamma_Rb85_stop3)...%RB-85starts with this line, Rb-85 F=2
       +Sb22/(2*(wa_Rb87_stop3+gs_detuning2+es_detuning2_2-w)+1j*gamma_Rb85_stop3)...%F=2
       +Sb21/(2*(wa_Rb87_stop3+gs_detuning2+es_detuning2_1-w)+1j*gamma_Rb85_stop3))...%F=2
       +Rb_85_F3_factor*(S32/(2*(wa_Rb87_stop3+gs_detuning3+es_detuning3_2-w)+1j*gamma_Rb85_stop3)...%F=3
       +S33/(2*(wa_Rb87_stop3+gs_detuning3+es_detuning3_3-w)+1j*gamma_Rb85_stop3)...%F=3
       +S34/(2*(wa_Rb87_stop3+gs_detuning3+es_detuning3_4-w)+1j*gamma_Rb85_stop3))));%F=3
   
     %the function we're integrating(i.e. this is the convolution with the
     %doppler broadening): 
  %just the real part? i wouldnt' think this would be correct, perhaps there's an overall j that i'm missing:
      eqn_to_int=@(w_int)constant...
       *(.28*(Rb_87_F2_factor*(S21./(2*(wa_Rb87_stop3+gs_detuning+es_detuning_1-w_int)+1j*gamma_Rb87_stop3)...
       +S22./(2*(wa_Rb87_stop3+gs_detuning+es_detuning_2-w_int)+1j*gamma_Rb87_stop3)...
       +S23./(2*(wa_Rb87_stop3+gs_detuning+es_detuning_3-w_int)+1j*gamma_Rb87_stop3))...
       +(Rb_87_F1_factor)*(S10./(2*(wa_Rb87_stop3+gs_detuning1+es_detuning1_0-w_int)+1j*gamma_Rb87_stop3)...
       +S11./(2*(wa_Rb87_stop3+gs_detuning1+es_detuning1_1-w_int)+1j*gamma_Rb87_stop3)...
       +S12./(2*(wa_Rb87_stop3+gs_detuning1+es_detuning1_2-w_int)+1j*gamma_Rb87_stop3)))...
       +.72*((Rb_85_F2_factor)*(Sb23./(2*(wa_Rb87_stop3+gs_detuning2+es_detuning2_3-w_int)+1j*gamma_Rb85_stop3)...%RB-85starts with this line
       +Sb22./(2*(wa_Rb87_stop3+gs_detuning2+es_detuning2_2-w_int)+1j*gamma_Rb85_stop3)...
       +Sb21./(2*(wa_Rb87_stop3+gs_detuning2+es_detuning2_1-w_int)+1j*gamma_Rb85_stop3))...
       +Rb_85_F3_factor*(S32./(2*(wa_Rb87_stop3+gs_detuning3+es_detuning3_2-w_int)+1j*gamma_Rb85_stop3)...
       +S33./(2*(wa_Rb87_stop3+gs_detuning3+es_detuning3_3-w_int)+1j*gamma_Rb85_stop3)...
       +S34./(2*(wa_Rb87_stop3+gs_detuning3+es_detuning3_4-w_int)+1j*gamma_Rb85_stop3))))...
       *sqrt(4*log(2)./(pi*delta_wd^2)).*exp(-4*log(2)*((w-w_int)./delta_wd).^2);
          
   %doppler broadened susceptibility
   %apparently we can use something called an 'anonymous function handler'
   %to do the integration inline
   chi2(index,2) = quad(eqn_to_int,w-10E9,w+10E9,1E-9);
   %note: changing the integration bounds 10 +-10GHz improved the look of
   %the curves.  
   abs(index,1)=exp(imag(chi2(index,2))*w/(c)*L);
    %so to summarize, 
    %chi is the un-doppler-broadened susceptibility
    %chi2 is the susceptibility featurning doppler broadening
    %abs is the absorption
   
   index=index+1;
end


%data_out(:,1)=(chi(:,1)-(wa_Rb87_stop3))/(2*pi);
data_out(:,1)=(chi(:,1))/(2*pi)/1E9;
data_out(:,2)=abs(:,1);



%%
figure(int16(T)+2000)
%figure(77)
%subplot(2,2,4)
plot((chi(:,1)-(wa_Rb87_stop3))/(2*pi)/1E9,(abs(:,1)),color)
hold on
%plot(data(:,1)/1E9,data(:,4),'*b');%not pumped
%plot(data(:,1)/1E9,data(:,2),'o--r');%pumped

%title(['1mm Cell Transmission ',int2str(delta_wd/(1000000*2*pi)),' MHz Doppler Broadened, N=',int2str(density_percc/(10^12)),'E12/cc T=',int2str(T),'deg C'])
%title(['T=',int2str(T),'deg C, ','N=',int2str(density_percc/(10^12)),'E12/cc, ',int2str(delta_wd/(1000000*2*pi)),' MHz Doppler Broadened'],'FontSize',16)
%title(['T=',int2str(T),'deg C, ','N=',int2str(density_percc/(10^13)),'E13/cc'],'FontSize',12)
title(['T=',int2str(T),'deg C, ','N=',num2str(density_percc/(10^14),2),'E14/cc'],'FontSize',16)

%h = legend([int2str(pp_87*100),'% Rb87 pumping  ',int2str(pp_85*100),'% Rb85 pumping'],'Exp w/ pumping',2,'Location','North');

h = legend([int2str(pp_87*100),'% Rb87 pumping  ',int2str(pp_85*100),'% Rb85 pumping'],'Exp w/o pumping','Exp w/ pumping',3,'Location','North');
  %  h = legend([int2str(pp_87*100),'% Rb87 pumping  ',int2str(pp_85*100),'% Rb85 pumping'],'Exp w/o pumping',2,'Location','North');
   % h = legend('no pumping fit','Exp w/o pumping',2,'Location','North');
    
    set(h,'Interpreter','none')

%xlabel('Freq (GHz) 0=384230GHz','FontSize',12)
xlabel('Freq (GHz)','FontSize',16)
ylabel('Transmission','FontSize',16)
%xlim([-6E9 8E9])
xlim([-6 8])
ylim([0 1.25])

%%
%%%%%need to process the incoming data slightly:
%data=data_8_16_2011; 
%data=data_90;
%data(:,1)=(data(:,1)-384230)*1E9;
%data(:,1)=(data(:,1)-.250E9);%(this is to account for error in frequency counter)
    

%%
%{
T0=273.15;
T1=T0+150;
P0=760;
%10torr at room temp -> 1/30 torr/K
buffer_gas_pressure=1/30*(T1);

n=((1/30*T1)/P0)*(T0/T1);
%n=(10/P0)*(T0/T1);

2000*n


%}


